% calculate disorientation angles in certain distance
% requires a map of unit quaternions representing orientations
% shifts the map and calculates the disorientations 
% (in the crystal system of the unshifted map)
% note, the routine is time consuming
% distantdisorientation requires about 1 s per call

function [meandisdistangle disoriangle] = distantdisorientation(Qa,Qb,Qc,Qd,ddx,ddy);

% creating filters
[xsteps ysteps] = size(Qa);
PNaN = ones(xsteps,ysteps);
if ddx > 0
    PNaN(1:ddx,1:ysteps) = 0/0;
elseif ddx < 0 
    PNaN((xsteps+ddx+1):xsteps,1:ysteps) = 0/0;
end;
if ddy > 0
    PNaN(1:xsteps,1:ddy) = 0/0;
elseif ddy < 0 
    PNaN(1:xsteps,(ysteps+ddy+1):ysteps) = 0/0;
end;

Pa = circshift(Qa,[ddx, ddy]).*PNaN;
Pb = circshift(Qb,[ddx, ddy]).*PNaN;
Pc = circshift(Qc,[ddx, ddy]).*PNaN;
Pd = circshift(Qd,[ddx, ddy]).*PNaN;

% calculate misorientation between shifted and original map
% (in the crsytal system of the unshifted map)
[Ra,Rb,Rc,Rd] = misorientation(Pa,Pb,Pc,Pd,Qa,Qb,Qc,Qd);
dQ = disorientation(Ra,Rb,Rc,Rd); 
disoriangle = 2*acosd(dQ);
disoriangle = disoriangle(disoriangle>=0); % list without NaN
meandisdistangle = mean(disoriangle);
%hdisdist = histcounts(disoriangle,edges);